import { message } from 'ant-design-vue';
import axios from 'axios';
import store from '@/store';

// 创建axios实例
const http = axios.create({
  baseURL: '/api', // 设置基础URL
});

// 请求拦截器
http.interceptors.request.use(config => {
  // 如果请求头中未携带authorization字段且store中存在token，则添加authorization字段
  if (!config.headers.authorization && store.state.token) {
    config.headers.authorization = store.state.token;
  }
  return config;
});

// 响应拦截器
http.interceptors.response.use(
  // 响应成功时的处理
  ({ data }) => {
    const { code } = data;
    if (code === 200) return data;
    console.error(data);
    throw data;
  },
  // 响应错误时的处理
  error => {
    // 如果网络未连接，则显示网络未连接的消息
    if (!navigator.onLine) {
      message.error('网络未连接');
    }
    throw error; // 抛出错误
  }
);

export default http; // 导出axios实例
